Constructors
-
RustLibApiImplPlatform({required BaseHandler handler, required RustLibWire wire, required GeneralizedFrbRustBinding generalizedFrbRustBinding, required PortManager portManager})
-
Properties
-
generalizedFrbRustBinding
→ GeneralizedFrbRustBinding
-
This is only intended to be used by automatically generated code,
instead of developers.
finalinherited
-
handler
→ BaseHandler
-
This is only intended to be used by automatically generated code,
instead of developers.
finalinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
portManager
→ PortManager
-
This is only intended to be used by automatically generated code,
instead of developers.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
wire
→ RustLibWire
-
This is only intended to be used by automatically generated code,
instead of developers.
finalinherited