RustLibApiImpl class

Inheritance
Implemented types

Constructors

RustLibApiImpl({required BaseHandler handler, required RustLibWire wire, required GeneralizedFrbRustBinding generalizedFrbRustBinding, required PortManager portManager})

Properties

generalizedFrbRustBinding → GeneralizedFrbRustBinding
This is only intended to be used by automatically generated code, instead of developers.
finalinherited
handler → BaseHandler
This is only intended to be used by automatically generated code, instead of developers.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
portManager → PortManager
This is only intended to be used by automatically generated code, instead of developers.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wire RustLibWire
This is only intended to be used by automatically generated code, instead of developers.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sse_decode_bool(SseDeserializer deserializer) bool
override
sse_decode_i_32(SseDeserializer deserializer) int
override
sse_encode_bool(bool self, SseSerializer serializer) → void
override
sse_encode_i_32(int self, SseSerializer serializer) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited